@@ -19,7 +19,7 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-     $Id: mb_linux.cpp 8643 2006-11-15 09:59:39Z luks $
+     $Id: mb_linux.cpp 691 2004-04-26 20:10:44Z robert $
 
 ----------------------------------------------------------------------------*/
 
@@ -159,12 +159,6 @@ bool DiskId::ReadTOC(MUSICBRAINZ_DEVICE device,
       close(fd);	
       return false;
    }
-   if (first < 1 || first > 99 || last < 1 || last > 99)
-   {
-      ReportError("Track numbers must be within range 1..99.");
-      close(fd);
-      return false;
-   }
 
    // Get the logical block address (lba) for the end of the audio data.
    // The "LEADOUT" track is the track beyond the final audio track
